# TUIDBTV

Terminal User interface DataBase Tables Viewer

based on [Textualize/textual](https://github.com/Textualize/textual)

---

#### Installation
```bash
sudo pip install tuidbtv
```
---
#### Run
```bash
tuidbtv
```
---
#### Requirments
- python >= 3.11
- textual
- psycopg
- mysql-connector-python

You may need to install psycopg binary distribution
```bash
pip install psycopg_binary
```
### Screenshots

![Screen1](/resources/screen1.png)
![Screen2](/resources/screen2.png)
![Screen3](/resources/screen3.png)
![Screen4](/resources/screen4.png)